;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; FILE: main.s
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;-----------------------------LICENSE NOTICE------------------------------------
;;    Crocker. A game for AmstradCPC.
;;    Copyright (C) 2018  Merienda
;;          Sara Vilaplana Rua
;;          Enrique Cortés Tarraga
;;
;;    This program is free software: you can redistribute it and/or modify
;;    it under the terms of the GNU General Public License as published by
;;    the Free Software Foundation, either version 3 of the License, or
;;    (at your option) any later version.
;;
;;    This program is distributed in the hope that it will be useful,
;;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;    GNU General Public License for more details.
;;
;;    You should have received a copy of the GNU General Public License
;;    along with this program.  If not, see <https://www.gnu.org/licenses/>.
;;-------------------------------------------------------------------------------

;; Include all CPCtelera constant definitions, macros and variables
.include "cpctelera.h.s"
.include "entity.h.s"
.include "main.h.s"

.globl _cocodrilo_palette
.globl _tileset_sprites_0
.globl _Mapa
;;
;; Start of _DATA area 
;;  SDCC requires at least _DATA and _CODE areas to be declared, but you may use
;;  any one of them for any purpose. Usually, compiler puts _DATA area contents
;;  right after _CODE area contents.
;;
.area _DATA

   ;; Define one Zero-terminated string to be used later on
   string: .asciz "Press ENTER to start"
   string2: .asciz "You ate!"
   string3: .asciz "Congratulations! You Win!"

.area _CODE

;;
;; MAIN function. This is the entry point of the application.
;;    _main:: global symbol is required for correctly compiling and linking
;;

_main::

   ;; Disable firmware to prevent it from interfering with string drawing
   call cpct_disableFirmware_asm

   ld    c, #0
   call cpct_setVideoMode_asm

   ld hl, #_cocodrilo_palette
   ld de, #16
   call cpct_setPalette_asm

;;(1B C) width	Width in tiles of the view window to be drawn
;;(1B B) height	Height in tiles of the view window to be drawn
;;(2B DE) tilemapWidth	Width in tiles of the complete tilemap
;;(2B HL) tileset	Pointer to the start of the tileset definition (list of 32-byte tiles).

    ;;ld  bc, #0x1928
    ;;ld  de, #40
    ;;ld  hl, #_tileset_sprites_0
    ;;call cpct_etm_setDrawTilemap4x8_ag_asm

;;(2B HL) memory	Video memory location where to draw the tilemap (character & 4-byte aligned)
;;(2B DE) tilemap	Pointer to the upper-left tile of the view to be drawn of the tilemap

    ;;ld  hl, #0xC000
    ;;ld  de, #_Mapa
    ;;call cpct_etm_drawTilemap4x8_ag_asm

;; Declare all function entry points as global symbols for the compiler.
;; (The linker will know what to do with them)
;; WARNING: Every global symbol declared will be linked, so DO NOT declare 
;; symbols for functions you do not use.

drawStart:

   ;; Set up draw char colours before calling draw string
   ld    h, #0         ;; H = Background PEN (0)
   ld    l, #6         ;; L = Foreground PEN (3)

   call cpct_setDrawCharM0_asm   ;; Set draw char colours

   ;; Print the string in video memory
   ;; HL already points to video memory, as it is the return
   ;; value from cpct_getScreenPtr_asm
   ld   iy, #string    ;; IY = Pointer to the string 
   ld h, #0xC3
   ld l, #0xC0

   call cpct_drawStringM0_asm  ;; Draw the string

start:

   call  cpct_scanKeyboard_asm
   ld    hl, #Key_Return
   call  cpct_isKeyPressed_asm
   jr    z, start
   jr borrar

borrar:

   ld    h, #0         ;; H = Background PEN (0)
   ld    l, #0         ;; L = Foreground PEN (3)

   call cpct_setDrawCharM0_asm   ;; Set draw char colours

   ld   iy, #string    ;; IY = Pointer to the string 
   ld h, #0xC3
   ld l, #0xC0

   call cpct_drawStringM0_asm  ;; Draw the string   

   jr loop

borrarString2:

   ld    h, #0         ;; H = Background PEN (0)
   ld    l, #0         ;; L = Foreground PEN (3)

   call cpct_setDrawCharM0_asm   ;; Set draw char colours

   ld   iy, #string2    ;; IY = Pointer to the string 
   ld h, #0xC3
   ld l, #0xC0

   call cpct_drawStringM0_asm
   
   ld   iy, #string3    ;; IY = Pointer to the string 
   ld h, #0xC4
   ld l, #0xC0

   call cpct_drawStringM0_asm   


   jr loop



restart:

   ;; Set up draw char colours before calling draw string
   ld    h, #0         ;; H = Background PEN (0)
   ld    l, #6         ;; L = Foreground PEN (3)

   call cpct_setDrawCharM0_asm   ;; Set draw char colours

   ;; Print the string in video memory
   ;; HL already points to video memory, as it is the return
   ;; value from cpct_getScreenPtr_asm
   ld   iy, #string2    ;; IY = Pointer to the string 
   ld h, #0xC3
   ld l, #0xC0

   call cpct_drawStringM0_asm  ;; Draw the string

   ld   iy, #string3    ;; IY = Pointer to the string 
   ld h, #0xC4
   ld l, #0xC0

    call cpct_drawStringM0_asm 

    jr start
   jr borrarString2

loop:
;;(2B HL) memory	Video memory location where to draw the tilemap (character & 4-byte aligned)
;;(2B DE) tilemap	Pointer to the upper-left tile of the view to be drawn of the tilemap


   ld   ix, #fuego
   call ent_draw_fuego

   ld   ix, #fuego1
   call ent_draw_fuego

   
   ld    ix, #hero_data
   call ent_clear
   call ent_update
   call ent_draw

    ld   ix, #bocadillo
   call ent_draw_bocata

   ld ix, #hero_data
   ld iy, #bocadillo
   call ent_checkCollisionBocadillo
   cp #0
   jr z, restart

   ld    ix, #camion2
   call ent_clear_coches
   call ent_update
   call ent_draw_camion

   ld    ix, #hero_data
   ld    iy, #camion2
   call ent_checkCollision

   ld    ix, #coche1
   call ent_clear_coches
   call ent_update
   call ent_draw_coches

   ld    ix, #hero_data
   ld    iy, #coche1
   call ent_checkCollision

   ld    ix, #coche2
   call ent_clear_coches
   call ent_update
   call ent_draw_coches

   ld    ix, #hero_data
   ld    iy, #coche2
   call ent_checkCollision


   call cpct_waitVSYNC_asm

   ;; Loop forever
   jr    loop